pub fn from_reader<R, T>(read: R) -> Result<T>where R: Read, T: DeserializeOwned,
Deserialize a value of type T from an io::Read source.
T
io::Read
This function will return an error if the source is not valid TOML.