Datetime

Struct Datetime 

pub struct Datetime {
    pub date: Option<LocalDate>,
    pub time: Option<LocalTime>,
    pub offset: Option<Offset>,
}
A TOML date-time value.

This struct can represent any of the TOML date-time types, depending on which fields are Some:

datetimeoffsettype
SomeSomeSomeOffset date-time
SomeSomeNoneLocal date-time
SomeNoneNoneLocal date
NoneSomeNoneLocal time

All other combinations are considered invalid

If compatibility with the toml crate is not needed, the AnyDatetime enum is recommended instead. Or when working with a known date-time type, one of the OffsetDatetime, LocalDatetime, LocalDate, or LocalTime types should be used.

Fields

date: Option<LocalDate>

The date portion of the date-time value.

time: Option<LocalTime>

The time portion of the date-time value.

offset: Option<Offset>

The UTC offset of the date-time value.

Implementations

Source

impl Datetime

pub fn from_slice(bytes: &[u8]) -> Result<Self, Error>

Parses a Datetime from a byte slice.

Errors

Returns an error if the slice is not a valid TOML date-time value.